package Ascii::Text::Font::Banner;

use Moo;

extends 'Ascii::Text::Font';

has character_height => (
	is => 'ro',
	default => sub { 7 }
);

sub character_A {
	my @character = $_[0]->default_character(8);
	$character[0][3] = $character[1][2] = $character[1][4] = $character[2][1] = $character[2][5] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][1] = $character[4][2] = $character[4][3] = $character[4][4] = $character[4][5] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][6] = '#';
	return \@character;
}

sub character_B {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][5] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
	return \@character;
}

sub character_C {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_D {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_E {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = '#';
	$character[1][0] = '#';
	$character[2][0] = '#';
	$character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = '#';
	$character[4][0] = '#';
	$character[5][0] = '#';
	$character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
	return \@character;
}

sub character_F {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[4][0] = $character[5][0] = $character[6][0] = '#';
	return \@character;
}

sub character_G {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = ' ';
	$character[1][1] = $character[1][2] = $character[1][3] = $character[1][4] = $character[1][5] = ' ';
	$character[2][1] = $character[2][2] = $character[2][3] = $character[2][4] = $character[2][5] = $character[2][6] = ' ';
	$character[3][1] = $character[3][2] = ' ';
	$character[4][1] = $character[4][2] = $character[4][3] = $character[4][4] = $character[4][5] = ' ';
	$character[5][1] = $character[5][2] = $character[5][3] = $character[5][4] = $character[5][5] = ' ';
	$character[6][0] = $character[6][6] = ' ';
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = '#';
	$character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[3][6] = $character[4][6] = $character[5][6] = '#';
	$character[6][1] = $character[6][3] = $character[6][4] = $character[6][5] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = '#';
	return \@character;
}

sub character_H {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[0][6] = $character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = $character[6][6] = '#';
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[0][6] = $character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = $character[6][6] = '#';
	return \@character;
}

sub character_I {
	my @character = $_[0]->default_character(8);
	$character[0][2] = $character[0][3] = $character[6][2] = $character[0][4] = $character[6][3] = $character[6][4] = $character[2][3] = $character[1][3] = $character[3][3] = $character[4][3] = $character[5][3] = '#';
	return \@character;
}

sub character_J {
	my @character = $_[0]->default_character(8);
	$character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][5] = $character[6][4] = $character[6][3] = $character[6][2] = $character[6][1] = $character[5][0] = $character[4][0] = '#';
	return \@character;
}

sub character_K {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][5] = $character[1][0] = $character[1][4] = $character[2][0] = $character[2][3] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][4] = $character[6][0] = $character[6][5] = '#';
	return \@character;
}

sub character_L {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
	return \@character;
}

sub character_M {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = $character[3][3] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][6] = $character[0][6] = '#';
	return \@character;
}

sub character_N {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[6][6] = $character[1][1] = $character[2][2] = $character[3][3] = $character[4][4] = $character[5][5] = '#';
	return \@character;
}

sub character_O {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
	return \@character;
}

sub character_P {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][6] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
	return \@character;
}

sub character_Q {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][4] = $character[4][6] = $character[5][0] = $character[5][5] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][6] = '#';
	return \@character;
}

sub character_R {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][6] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][4] = $character[5][5] = $character[6][6] = '#';
	return \@character;
}

sub character_S {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = '#';
	$character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
	$character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	$character[1][0] = $character[2][0] = '#';
	$character[1][6] = '#';
	$character[4][6] = $character[5][6] = '#';
	$character[5][0] = '#';
	return \@character;
}

sub character_T {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = '#';
	$character[0][4] = $character[0][5] = $character[0][6] = '#';
	$character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = '#';
	$character[5][3] = $character[6][3] = '#';
	return \@character;
}

sub character_U {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = '#';
	$character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = '#';
	$character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_V {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][6] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = '#';
	$character[4][1] = $character[4][5] = $character[5][2] = $character[5][4] = $character[6][3] = '#';
	return \@character;
}

sub character_W {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[0][6] = $character[1][6] = $character[2][6] = $character[3][6] = $character[4][6] = $character[5][6] = $character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = $character[5][3] = $character[6][1] = $character[6][2] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_X {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][6] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = $character[3][3] = $character[4][2] = $character[4][4] = $character[5][1] = $character[5][5] = $character[6][0] = $character[6][6] = '#';
	return \@character;
}

sub character_Y {
	my @character = $_[0]->default_character(8);
	$character[3][3] = $character[4][3] = $character[5][3] = $character[6][3] = $character[0][0] = $character[0][6] = $character[1][1] = $character[1][5] = $character[2][2] = $character[2][4] = '#';
	return \@character;
}

sub character_Z {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = $character[1][5] = $character[2][4] = $character[3][3] = $character[4][2] = $character[5][1] = '#';
	return \@character;
}

sub character_a {
	my @character = $_[0]->default_character(5);
	$character[3][1] = $character[3][2] = $character[3][3] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][2] = $character[5][3] = $character[6][1] = $character[6][3] = '#';
	return \@character;
}

sub character_b {
	my @character = $_[0]->default_character(5);
	$character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
	return \@character;
}

sub character_c {
	my @character = $_[0]->default_character(5);
	$character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][2] = $character[6][1] = '#';
	return \@character;
}

sub character_d {
	my @character = $_[0]->default_character(5);
	$character[1][3] = $character[2][3] = $character[3][3] = $character[4][3] = $character[5][3] = $character[6][3] = '#';
	$character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][1] = $character[6][2] = '#';
	return \@character;
}

sub character_e {
	my @character = $_[0]->default_character(6);
	$character[3][1] = $character[3][2] = $character[4][0] = $character[4][2] = $character[4][3] = $character[5][0] = $character[5][1] = $character[6][1] = $character[6][2] = '#';
	return \@character;
}

sub character_f {
	my @character = $_[0]->default_character(5);
	$character[1][2] = $character[2][1] = $character[2][3] = $character[3][1] = $character[4][0] = $character[4][1] = $character[4][2] = $character[5][1] = $character[6][1] = '#';
	return \@character;
}

sub character_g {
	my @character = $_[0]->default_character(5);
	$character[2][1] = $character[2][2] = $character[2][3] = $character[3][0] = $character[3][3] = $character[4][1] = $character[4][2] = $character[5][0] = $character[6][1] = $character[6][2] = $character[6][3] = '#';
	return \@character;
}

sub character_h {
	my @character = $_[0]->default_character(5);
	$character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][3] = '#';
	return \@character;
}

sub character_i {
	my @character = $_[0]->default_character(5);
	$character[1][1] = $character[3][1] = $character[3][0] = $character[4][1] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
	return \@character;
}

sub character_j {
	my @character = $_[0]->default_character(5);
	$character[1][2] = $character[3][2] = $character[4][2] = $character[5][0] = $character[5][2] = $character[6][1] = '#';
	return \@character;
}

sub character_k {
	my @character = $_[0]->default_character(5);
	$character[1][0] = $character[2][0] = $character[3][0] = $character[4][0] = $character[5][0] = $character[6][0] = $character[3][2] = $character[4][1] = $character[5][2] = $character[6][3] = '#';
	return \@character;
}

sub character_l {
	my @character = $_[0]->default_character(4);
	$character[1][0] = $character[1][1] = $character[2][1] = $character[3][1] = $character[4][1] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = '#';
	return \@character;
}

sub character_m {
	my @character = $_[0]->default_character(7);
	$character[4][0] = $character[5][0] = $character[6][0] = $character[3][1] = $character[3][4] = $character[4][2] = $character[4][3] = $character[4][5] = $character[6][5] = $character[5][5] = '#';

	return \@character;
}

sub character_n {
	my @character = $_[0]->default_character(4);
	$character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][0] = $character[6][3] = '#';
	return \@character;
}

sub character_o {
	my @character = $_[0]->default_character(6);
	$character[3][2] = $character[3][3] = $character[4][1] = $character[4][4] = $character[5][1] = $character[5][4] = $character[6][2] = $character[6][3] = '#';
	return \@character;
}

sub character_p {
	my @character = $_[0]->default_character(4);
	$character[2][0] = $character[2][1] = $character[2][2] = $character[3][0] = $character[4][0] = $character[5][0] = $character[5][1] = $character[5][2] = $character[6][0] = $character[3][3] = $character[4][3] = '#';
	return \@character;
}

sub character_q {
	my @character = $_[0]->default_character(8);
	$character[2][3] = $character[2][4] = $character[2][5]  = $character[3][2] = $character[3][6] = $character[4][2] = $character[4][6] = $character[5][3] = $character[5][4] = $character[5][5]  = $character[6][6] = '#';
	
	return \@character;
}

sub character_r {
	my @character = $_[0]->default_character(5);
	$character[3][0] = $character[3][1] = $character[3][2] = $character[4][0] = $character[5][0] = $character[6][0] = $character[4][3] = '#';		
	return \@character;
}

sub character_s {
	my @character = $_[0]->default_character(5);
	$character[3][1] = $character[3][2] = $character[3][3] = $character[4][0] = $character[4][1] = $character[5][2] = $character[5][3] = $character[6][0] =$character[6][1] = $character[6][2]  = '#';
	return \@character;
}

sub character_t {
	my @character = $_[0]->default_character(5);
	$character[1][1] = $character[2][1] = $character[3][0] = $character[3][1] = $character[3][2] = $character[4][1] = $character[5][1] = $character[6][2] = $character[6][3] = '#';
	return \@character;
}

sub character_u {
	my @character = $_[0]->default_character(5);
	$character[3][0] = $character[3][3] = $character[4][0] = $character[4][3] = $character[5][0] = $character[5][3] = $character[6][1] = $character[6][2] = $character[6][3] = '#';

	return \@character;
}

sub character_v {
	my @character = $_[0]->default_character(6);
	$character[3][0] = $character[4][0] = $character[5][1] = $character[6][2] = $character[5][3] = $character[4][4] = $character[3][4] = '#';
	return \@character;
}

sub character_w {
	my @character = $_[0]->default_character(6);
	$character[3][0] = $character[3][4] = $character[4][0] = $character[4][4] = $character[5][0] = $character[5][2] = $character[5][4] = $character[6][0] = $character[6][1] = $character[6][3] = $character[6][4] = '#';
	return \@character;
}

sub character_x {
	my @character = $_[0]->default_character(5);
	$character[3][0] = $character[3][3] = $character[4][1] = $character[4][2] = $character[5][1] = $character[5][2] = $character[6][0] = $character[6][3] = '#';
	return \@character;
}

sub character_y {
	my @character = $_[0]->default_character(5);
	$character[3][0] = $character[3][3] = $character[4][1] = $character[4][3] = $character[5][2] = $character[6][1] = '#';

	return \@character;
}

sub character_z {
	my @character = $_[0]->default_character(5);
	$character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[4][2] = $character[5][1] = $character[6][0] = $character[6][1] = $character[6][2] = $character[6][3] ='#';
	return \@character;
}

sub character_0 {
	my @character = $_[0]->default_character(8);
	$character[0][2] = $character[0][3] = $character[0][4] = $character[1][1] = $character[1][5] = $character[2][0] = $character[2][6] = $character[3][0] = $character[3][6] = $character[4][0] = $character[4][6] = $character[5][1] = $character[5][5] = $character[6][2] = $character[6][3] = $character[6][4] = '#';
	return \@character;
}

sub character_1 {
	my @character = $_[0]->default_character(6);
	$character[0][2] = $character[1][2] = $character[2][2] = $character[3][2] = $character[4][2] = $character[5][2] = $character[6][2] = '#';
	$character[6][0] = $character[6][1] = $character[6][3] = $character[6][4] = '#';
	$character[2][0] = $character[1][1] = '#';
	return \@character;
}

sub character_2 {
	my @character = $_[0]->default_character(8);
	$character[0][1]=$character[0][2]=$character[0][3]=$character[0][4]=$character[0][5]=$character[1][0]=$character[1][6]=$character[2][6]=$character[3][5]=$character[3][4]=$character[3][3]='#';
	$character[3][2]=$character[3][1]='#';
	$character[4][0]=$character[5][0]=$character[6][0]=$character[6][1]=$character[6][2]=$character[6][3]='#';
	$character[6][4]=$character[6][5]=$character[6][6]='#';
	return \@character;
}

sub character_3 {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = '#';
	$character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][6] = '#';
	$character[5][0] = $character[6][1] = $character[5][6] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_4 {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[1][0] = $character[2][0] = $character[3][0] = '#';
	$character[1][5] = $character[2][5] = $character[3][5] = '#';
	$character[4][1] = $character[4][2] = $character[4][3] = $character[4][4] = $character[4][5] = $character[4][6] = '#';
	$character[5][5] = $character[6][5] = '#';
	return \@character;
}

sub character_5 {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_6 {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[3][0] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[4][0] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	return \@character;
}

sub character_7 {
	my @character = $_[0]->default_character(8);
	$character[0][0] = $character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[0][6] = $character[1][0] = $character[1][5] = $character[2][4] = $character[3][3] = $character[4][2] = $character[5][2] = $character[6][2] = '#';
	return \@character;
}

sub character_8 {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = '#';
	$character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = '#';
	$character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = '#';
	$character[1][0] = $character[2][0] = $character[4][0] = $character[5][0] = '#';
	$character[1][6] = $character[2][6] = $character[4][6] = $character[5][6] = '#';
	return \@character;
}

sub character_9 {
	my @character = $_[0]->default_character(8);
	$character[0][1] = $character[0][2] = $character[0][3] = $character[0][4] = $character[0][5] = $character[1][0] = $character[1][6] = $character[2][0] = $character[2][6] = $character[3][1] = $character[3][2] = $character[3][3] = $character[3][4] = $character[3][5] = $character[3][6] = $character[4][6] = $character[5][0] = $character[5][6] = $character[6][1] = $character[6][2] = $character[6][3] = $character[6][4] = $character[6][5] = $character[6][6] = '#';
	return \@character;
}

sub space {
	my @character = $_[0]->default_character(8);
	return \@character;
}

1;

__END__

=head1 NAME

Ascii::Text::Font::Boomer - Boomer font

=head1 VERSION

Version 0.06

=cut

=head1 SYNOPSIS

	use Ascii::Text::Font::Boomer;

	my $font = Ascii::Text::Font::Boomer->new();

	$font->character_A;

=head1 SUBROUTINES/METHODS

=head2 new

Instantiate a new Ascii::Text::Font::Boomer object.

	my $font = Ascii::Text::Font::Boomer->new();

=head2 character_A


=head2 character_B


=head2 character_C


=head2 character_D


=head2 character_E


=head2 character_F


=head2 character_G


=head2 character_H


=head2 character_I


=head2 character_J


=head2 character_K


=head2 character_L


=head2 character_M


=head2 character_N


=head2 character_O


=head2 character_P


=head2 character_Q


=head2 character_R


=head2 character_S


=head2 character_T


=head2 character_U


=head2 character_V


=head2 character_W


=head2 character_X


=head2 character_Y


=head2 character_Z


=head2 character_a


=head2 character_b


=head2 character_c


=head2 character_d


=head2 character_e


=head2 character_f


=head2 character_g


=head2 character_h


=head2 character_i


=head2 character_j


=head2 character_k


=head2 character_l


=head2 character_m


=head2 character_n


=head2 character_o


=head2 character_p


=head2 character_q


=head2 character_r


=head2 character_s


=head2 character_t


=head2 character_u


=head2 character_v


=head2 character_w


=head2 character_x


=head2 character_y


=head2 character_z


=head2 character_0


=head2 character_1


=head2 character_2


=head2 character_3


=head2 character_4


=head2 character_5


=head2 character_6


=head2 character_7

       
=head2 character_8


=head2 character_9

       
=head1 AUTHOR

LNATION, C<< <email at lnation.org> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-ascii-text at rt.cpan.org>, or through
the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Ascii-Text>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Ascii::Text

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=Ascii-Text>

=item * CPAN Ratings

L<https://cpanratings.perl.org/d/Ascii-Text>

=item * Search CPAN

L<https://metacpan.org/release/Ascii-Text>

=back

=head1 ACKNOWLEDGEMENTS

=head1 LICENSE AND COPYRIGHT

This software is Copyright (c) 2024 by LNATION.

This is free software, licensed under:

  The Artistic License 2.0 (GPL Compatible)

=cut



